#$Id: webfwlog.spec 701 2019-09-20 23:14:39Z bhockney $
# (C) 2003 - 2018 by Bob Hockney <zeus@ix.netcom.com>
#
# Spec file for webfwlog
#
# Webfwlog is distributed under the terms of GNU GPL

%define debug_package %{nil}

# Set html_doc_root to the webserver document root where you want to install webfwlog.
# A symlink will be created in this directory as webfwlog pointing to %%{_datadir}/webfwlog
%{!?html_doc_root:%global html_doc_root /var/www/html}

# Set webserver_group to a group to which the user the webserver process runs as belongs
%{!?webserver_group:%global webserver_group apache}

# enable_syslog builds syslog support
%{!?enable_syslog:%global enable_syslog 1}

# with_mysql supports mysql for syslog
# with_pgsql supports postgresql for syslog
# 
# Using a database server is highly recommended
%{!?with_mysql:%global with_mysql 0}
%{!?with_pgsql:%global with_pgsql 0}

# enable_mysql_ipv6 builds mysql shared library, which is needed for ipv6 with mysql
%{!?enable_mysql_ipv6:%global enable_mysql_ipv6 1}

# enable libmaxminddb for full geoip support for syslog parser
%{!?with_libmaxminddb:%global with_libmaxminddb 1}

Summary: Web-based firewall log analyzer
Name: webfwlog
Version: 1.1.3
Release: 1 
License: GPL
URL: http://www.webfwlog.net
Group: Applications/Internet
Packager: Bob Hockney <zeus@ix.netcom.com>
BuildRoot: %{_tmppath}/%{name}-%{version}-root
Prefix: %{_prefix}
Prefix: %{html_doc_root}
Source: http://devel.webfwlog.net/download/v1.1/%{name}-%{version}.tar.gz
# These are absolute requirements
Requires: webserver
Requires: php >= 5.4

%if %{enable_syslog}
BuildRequires: glibc-devel
%if %{with_mysql}
%define plugin_dir %(mysql_config --plugindir)
BuildRequires: mysql-devel >= 5
Requires: mysql >= 5
%endif
%if %{with_pgsql}
BuildRequires: postgresql-devel >= 7.4
Requires: postgresql >= 7.4
%endif
# zlib is optional but recommended
BuildRequires: zlib-devel >= 1.0.9
Requires: zlib >= 1.0.9
%endif
%if %{with_libmaxminddb}
BuildRequires: libmaxminddb-devel >= 1.0
BuildRequires: libdb-devel
Requires: libmaxminddb >= 1.0
Requires: libdb
%endif

%description
Webfwlog is a flexible web-based analysis and reporting tool for firewall logs.
It supports standard system logs for linux, FreeBSD, OpenBSD, NetBSD, Solaris,
Irix, Darwin, etc. as well as Cisco routers and Windows XP.  Supported log file
formats are netfilter, ipfilter, ipfw, ipchains, cisco routers and Windows XP.
Webfwlog also supports logs saved in a database using the ULOG or NFLOG targets
of the linux netfilter project. It includes support for IPv6, as well as
Maxmind's GeoIP version 2 location databases. 

With Webfwlog you can design reports to use on your logged data in whatever 
configuration you desire.  Included are example reports as a starting point.
You can sort a report with a single click, "drill-down" on the reports all the
way to the packet level, and save report definitions for later use.  You can
also create a link directly to any saved report definition.

%prep
%setup -q

%build
# configure should be able to find the shared libraries for mysql and postgresql
#   automagically, but if it cannot you can add =[DIR] to --with-mysql and/or
#   --with-pgsql to tell configure where to look for them.

%configure \
	--with-html-doc-root=%{html_doc_root} \
%if %{enable_syslog}
	--enable-syslog \
%endif
%if %{enable_syslog} && %{with_mysql}
	--with-mysql \
%if %{enable_mysql_ipv6}
	--enable-mysql-ipv6=%{plugin_dir} \
%endif
%endif
%if %{enable_syslog} && %{with_pgsql}
	--with-pgsql \
%endif
%if %{enable_syslog} && %{with_libmaxminddb}
	--with-libmaxminddb \
        --with-libdb \
%endif


make

%install
rm -rf %{buildroot}
mkdir -p %{buildroot}%{_sysconfdir}
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_datadir}/webfwlog
%if %{enable_mysql_ipv6}
mkdir -p %{buildroot}%{plugin_dir}
%endif
mkdir -p %{buildroot}%{html_doc_root}
make DESTDIR=%{buildroot} install
rm -f %{buildroot}%{html_doc_root}/webfwlog

%post
if test -d %{html_doc_root}/webfwlog; then rm -rf %{html_doc_root}/webfwlog; fi;
if test -L %{html_doc_root}/webfwlog; then rm -f %{html_doc_root}/webfwlog; fi;
ln -s %{_datadir}/webfwlog %{html_doc_root}/webfwlog

%postun
rm -f %{html_doc_root}/webfwlog

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,0555)
%if %{enable_syslog}
%attr(4550,root,%{webserver_group}) %{_bindir}/wfwl_syslog
%endif
%config(noreplace) %attr(0640,root,%{webserver_group}) %{_sysconfdir}/webfwlog.conf
%{_datadir}/webfwlog
%{_datadir}/webfwlog-vendor
%if %{enable_mysql_ipv6} && %{with_mysql}
%{plugin_dir}/libwebfwlog_udf.*
%endif
%doc COPYING AUTHORS README README.geoip README.pdf INSTALL CREDITS
%doc ChangeLog ReleaseNotes
%doc examples contrib
%doc mysql pgsql
%doc webfwlog.conf

%changelog
* Thu Nov 16 2023 Bob Hockney <zeus@ix.netcom.com>
- update for webfwlog-1.1.3

* Fri Sep 20 2019 Bob Hockney <zeus@ix.netcom.com>
- update for webfwlog-1.1.2

* Thu Nov 8 2018 Bob Hockney <zeus@ix.netcom.com>
- update for webfwlog-1.1.1

* Fri Aug 5 2016 Bob Hockney <zeus@ix.netcom.com>
- update for webfwlog-1.1.0

* Fri Oct 31 2014 Bob Hockney <zeus@ix.netcom.com>
- update for webfwlog-1.01

* Mon May 19 2014 Bob Hockney <zeus@ix.netcom.com>
- update for webfwlog-1.00

* Tue Jun 8 2010 Bob Hockney <zeus@ix.netcom.com>
- fix warnings when date.timezone not set in php.ini with php >= 5.3

* Tue Oct 27 2009 Bob Hockney <zeus@ix.netcom.com>
- fix problem with tcp options exact match always being set (syslog)

* Mon Oct 12 2009 Bob Hockney <zeus@ix.netcom.com>
- update for webfwlog-0.94

* Thu Dec 13 2007 Bob Hockney <zeus@ix.netcom.com>
- Fix problem with sorting with ulogd and MySQL in some cases

* Thu May 31 2007 Bob Hockney <zeus@ix.netcom.com>
- update for webfwlog-0.93

* Thu Jun 15 2006 Bob Hockney <zeus@ix.netcom.com>
- fix mysql setup script to grant needed additional rights

* Sat Jun 10 2006 Bob Hockney <zeus@ix.netcom.com>
- fix url for GNU getdate syntax documentation

* Sat Mar 4 2006 Bob Hockney <zeus@ix.netcom.com>
- update for webfwlog-0.92

* Thu Apr 21 2005 Bob Hockney <zeus@ix.netcom.com>
- update for webfwlog-0.91

* Sun Dec 5 2004 Bob Hockney <zeus@ix.netcom.com>
- Fix problem using postgresql without ulog
- Get default_data_source to work right
- Tweak example reports

* Sun Nov 21 2004 Bob Hockney <zeus@ix.netcom.com>
- Initial RPM package for webfwlog-0.90
